@@ -3,7 +3,6 @@ Convenience decorators for use in fabfiles.
 """
 
 from functools import wraps
-from types import StringTypes
 
 
 def hosts(*host_list):
@@ -35,7 +34,7 @@ def hosts(*host_list):
             return func(*args, **kwargs)
         _hosts = host_list
         # Allow for single iterable argument as well as *args
-        if len(_hosts) == 1 and not isinstance(_hosts[0], StringTypes):
+        if len(_hosts) == 1 and not isinstance(_hosts[0], basestring):
             _hosts = _hosts[0]
         inner_decorator.hosts = list(_hosts)
         return inner_decorator
@@ -75,7 +74,7 @@ def roles(*role_list):
             return func(*args, **kwargs)
         _roles = role_list
         # Allow for single iterable argument as well as *args
-        if len(_roles) == 1 and not isinstance(_roles[0], StringTypes):
+        if len(_roles) == 1 and not isinstance(_roles[0], basestring):
             _roles = _roles[0]
         inner_decorator.roles = list(_roles)
         return inner_decorator
@@ -91,13 +90,12 @@ def runs_once(func):
     typical use means "once per invocation of the ``fab`` program".
 
     Any function wrapped with this decorator will silently fail to execute the
-    2nd, 3rd, ..., Nth time it is called, and will return None in that instance.
+    2nd, 3rd, ..., Nth time it is called, and will return the value of the
+    original run.
     """
     @wraps(func)
     def decorated(*args, **kwargs):
-        if hasattr(decorated, 'has_run'):
-            return
-        else:
-            decorated.has_run = True
-            return func(*args, **kwargs)
+        if not hasattr(decorated, 'return_value'):
+            decorated.return_value = func(*args, **kwargs)
+        return decorated.return_value
     return decorated
