@@ -271,7 +271,9 @@ def default_channel():
     """
     Return a channel object based on ``env.host_string``.
     """
-    return connections[env.host_string].get_transport().open_session()
+    chan = connections[env.host_string].get_transport().open_session()
+    chan.input_enabled = True
+    return chan
 
 
 #
@@ -355,3 +357,10 @@ output = _AliasDict({
     'everything': ['warnings', 'running', 'user', 'output'],
     'output': ['stdout', 'stderr']
 })
+
+
+#
+# I/O loop sleep parameter (in seconds)
+#
+
+io_sleep = 0.01
